@@ -19,12 +19,12 @@ pushd mosquitto-0.9.1.$SVNVER
 echo y | dh_make --createorig --single -e yuvraaj@gmail.com -c lgpl
 
 # Create everything for mosquitto
-cp build-files/postinst.mosquitto debian/postinst
 cp build-files/mosquitto.control debian/control
 cp build-files/mosquitto.rules debian/rules
 cp build-files/mosquitto.install debian/
+
 dpkg-buildpackage -rfakeroot -sa -S
-dput -f $1-extras-builder ./mosquitto*.changes
+dput -f $1-extras-builder ../mosquitto*.changes
 #dpkg-buildpackage -rfakeroot
 
 popd
